% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MANTIS.R
\name{calcSingleStrainDominance}
\alias{calcSingleStrainDominance}
\title{Calculate a measure of single-strain dominance (SSD) (\code{epsilon}).}
\usage{
calcSingleStrainDominance(data, xiObs = 0.5, xfObs = 1, method = "host")
}
\arguments{
\item{data}{the list as obtained from running the simulation. See \code{?runMANTIS} for details.}

\item{xiObs}{the starting proportion of time to use for diversity. For example \code{xiObs=0.5} will start from the middle of the time-series.}

\item{xfObs}{the end proportion of time to use for diversity.}

\item{method}{a character string to choose the method to be used. Methods are \code{"host"} and \code{"strain"} and relate to how total 
prevalence of the pathogen is estimated. When \code{method="host"} the function \code{extractPathogenPrevByStrain} is called and when \code{method="strain"} 
the function \code{extractPathogenPrevByHost} is called. See the help of each function for how they differ. Estimations are expected to be very similar using the two methods.}
}
\value{
epsilon
}
\description{
This function estimates a measure of SSD for a simulated time-series of infectious individuals (Y). 
Single-strain dominance can be quantified by \code{epsilon}, the measure obtained by comparing the relative prevalence of the two
most common antigenic variants within single epidemics and then averaging across extended periods of time, or, more formally, averaging
across each of the epidemics within the studied time window. The number and time point of each epidemic \code{Pi} is determined by addressing
total pathogen prevalence and identifying local maxima. Here, two estimates of total pathogen prevalence can be used via the argument \code{method}, see bellow.
\code{epsilon} is expected to vary between 0 and 1, with high values indicative of strong SSD within epidemics, 
as often found, for instance, in the antigenic evolution and epidemiological behaviour of influenza A viruses. \code{epsilon} 
has been used in several research publications - see references (2) and (5) for formal definitions (found in the documentation or output of function \code{readingMANTIS}).
}

